@@ -33,13 +33,11 @@ def source(file: str, ref: Optional[vs.VideoNode] = None,
     Alias for this function is `lvsfunc.src`.
 
     Dependencies:
-
-        * ffms2
-        * L-SMASH (optional: m2ts sources or when forcing lsmas)
-        * d2vsource (optional: d2v sources)
-        * dgdecodenv (optional: dgi sources)
-        * mvsfunc (optional: reference clip mode)
-        * vapoursynth-readmpls (optional: mpls sources)
+    * ffms2
+    * L-SMASH-Works (optional: m2ts sources or when forcing lsmas)
+    * d2vsource (optional: d2v sources)
+    * dgdecodenv (optional: dgi sources)
+    * VapourSynth-ReadMpls (optional: mpls sources)
 
     :param file:              Input file
     :param ref:               Use another clip as reference for the clip's format,
@@ -53,8 +51,7 @@ def source(file: str, ref: Optional[vs.VideoNode] = None,
     :return:                  Vapoursynth clip representing input file
     """
 
-    # TODO: Consider adding kwargs for additional options,
-    #       find a way to NOT have to rely on a million elif's
+    # TODO: find a way to NOT have to rely on a million elif's
     if file.startswith('file:///'):
         file = file[8::]
 
@@ -85,16 +82,11 @@ def source(file: str, ref: Optional[vs.VideoNode] = None,
             clip = core.ffms2.Source(file, **index_args)
 
     if ref:
-        try:
-            from mvsfunc import GetMatrix
-        except ModuleNotFoundError:
-            raise ModuleNotFoundError("source: missing dependency 'mvsfunc'")
-
         if ref.format is None:
             raise ValueError("source: 'Variable-format clips not supported.'")
         clip = core.std.AssumeFPS(clip, fpsnum=ref.fps.numerator, fpsden=ref.fps.denominator)
         clip = core.resize.Bicubic(clip, width=ref.width, height=ref.height,
-                                   format=ref.format.id, matrix_s=str(GetMatrix(ref)))
+                                   format=ref.format.id, matrix_s=str(get_matrix(ref)))
         if is_image(file):
             clip = clip * (ref.num_frames - 1)
 
@@ -157,7 +149,8 @@ def edgefixer(clip: vs.VideoNode,
 
     Alias for this function is `lvsfunc.ef`.
 
-    Dependencies: vs-continuityfixer
+    Dependencies:
+    * VS-ContinuityFixer
 
     :param clip:        Input clip
     :param left:        Number of pixels to fix on the left (Default: None)
@@ -183,6 +176,28 @@ def edgefixer(clip: vs.VideoNode,
     return ef if full_range else core.std.Limiter(ef, 16.0, [235, 240])
 
 
+def get_matrix(clip: vs.VideoNode) -> int:
+    """
+    Helper function to get the matrix for a clip.
+
+    :param clip:    src clip
+
+    :return:        Value representing a matrix
+    """
+    frame = clip.get_frame(0)
+    w, h = frame.width, frame.height
+
+    if frame.format.color_family == vs.RGB:
+        return 0
+    if frame.format.color_family == vs.YCOCG:
+        return 8
+    if w <= 1024 and h <= 576:
+        return 5
+    if w <= 2048 and h <= 1536:
+        return 1
+    return 9
+
+
 def shift_tint(clip: vs.VideoNode, values: Union[int, Sequence[int]] = 16) -> vs.VideoNode:
     """
     A function for forcibly adding pixel values to a clip.
@@ -268,7 +283,8 @@ def wipe_row(clip: vs.VideoNode,
 
     if width2, height2, etc. are given, it will merge the two masks.
 
-    Dependencies: kagefunc
+    Dependencies:
+    * kagefunc
 
     :param clip:           Input clip
     :param secondary:      Clip to replace wiped rows with (Default: None)
@@ -534,9 +550,3 @@ def scale_thresh(thresh: float, clip: vs.VideoNode, assume: Optional[int] = None
 
 # TODO: Write function that only masks px of a certain color/threshold of colors.
 #       Think the magic wand tool in various image-editing programs.
-
-
-# TODO: Write a wrapper for duplex's Chroma Reconstructor.
-#       It should optimally be able to accept anything and accurately reconstruct it,
-#       so long as the user gives it the right clips. Otherwise, it should assume
-#       that the chroma was scaled down using Nearest Neighbor or something alike.
